/******************************************************************************
 * Copyright (C) 2004, 2005 Alex Karev.
 *
 * This file is part of gtkpivo library.
 *
 * gtkpivo library is free software; you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation version 2.1 of the License.
 *
 * gtkpivo library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with gtkpivo library; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA
 *
 ******************************************************************************/
/* vim: set ts=4 sw=4 : */

#include "gtkpivofactory.h"
#include "gtkpivo.h"

GtkWidget *
gtk_pivo_factory_create_widget(const gchar *wname, GtkAdjustment *adj, gchar *label,...)
{
	GtkWidget *widget = NULL;
	/** Should be not a problem if used inside gdk thread lock */
	static GtkTooltips *tips = NULL;
	
	g_return_val_if_fail(wname != NULL, NULL);

	if (NULL == tips) {
		tips = gtk_tooltips_new();
		gtk_tooltips_enable( GTK_TOOLTIPS(tips));
	}

	if (g_strrstr(wname, "GtkTrend") != NULL) {
		widget = gtk_trend_new(label, adj, NULL, NULL, NULL);
	} else if (g_strrstr(wname, "GtkTaho")) {
		widget = gtk_taho_new(adj, label, NULL);
	} else if (g_strrstr(wname, "GtkIOField")) {
		widget = gtk_iofield_new(adj, label);
	} else if (g_strrstr(wname, "GtkBar")) {
		widget = gtk_progress_bar_new_with_adjustment(adj);
		gtk_progress_bar_set_orientation(GTK_PROGRESS_BAR(widget), 
				GTK_PROGRESS_BOTTOM_TO_TOP);
	} else if (g_strrstr(wname, "GtkLed")) {
		g_print("Generating led\n");
		widget = gtk_led_new(adj, label);
	} else if (g_strrstr(wname, "GtkButton")) {
		widget = gtk_button_new_with_label(label);
	} 

	if (NULL != widget) {
		gtk_widget_show(widget);
		gtk_tooltips_set_tip(GTK_TOOLTIPS(tips), widget, label, "test1");
	}

	return (widget);
}

